@@ -3,19 +3,16 @@ mod consts;
 mod utils;
 
 use std::fs::File;
-use std::io::{Read, Write};
+use std::io::Read;
 
 
-pub fn from_file(input: &str, output: &str) {
+pub fn from_file(input: &str) -> String {
 
     let mut f = File::open(input).unwrap();
     let mut st = String::new();
 
     f.read_to_string(&mut st).unwrap();
-    let result = crate::markdown::render(&st).unwrap();
-
-    let mut f = File::create(output).unwrap();
-    f.write_all(result.as_bytes()).unwrap();
+    crate::markdown::render(&st).unwrap()
 }
 
 
