@@ -119,20 +119,32 @@ fn construct_code_fence(mut lines: Vec<Line>, mut options: CodeFenceOption, synt
         _ => {}
     }
 
+    let code_indent = lines[0].indent;
     let mut content = Vec::with_capacity(lines.len() * 3);
+    let lines_length = lines.len();
 
-    // all those messes are to remove a trailing `\n`
-    for (ind, ln) in lines.iter().enumerate() {
+    for (ind, ln) in lines.iter_mut().enumerate() {
 
-        if ind + 1 < lines.len() {
+        // removes trailing `\n`
+        if ind + 1 < lines_length {
             content.push(render_line_number(&mut options));
         }
 
+        if ln.indent > code_indent {
+            ln.indent -= code_indent;
+        }
+
+        else {
+            ln.indent = 0;
+        }
+
         content.push(ln.into_raw());
         content.push(vec![U16_NEWLINE]);
     }
 
+    // removes trailing `\n`
     result.content = content[0..content.len() - 1].concat();
+
     result.content = prevent_backslash_escape(&result.content);
 
     result
