@@ -1,5 +1,4 @@
 use crate::utils::{get_bracket_end_index, get_parenthesis_end_index, remove_special_characters};
-use crate::markdown::escape::undo_html_escapes_safely;
 use crate::markdown::inline::decoration::render_italic;
 use crate::consts::*;
 
@@ -23,7 +22,7 @@ pub fn render_link(content: &Vec<u16>) -> Vec<u16> {
 
                 vec![
                     vec![U16_LESS_THAN, U16_SMALL_I, U16_SMALL_M, U16_SMALL_G, U16_SPACE, U16_SMALL_S, U16_SMALL_R, U16_SMALL_C, U16_EQUAL, U16_DOUBLE_QUOTE],
-                    undo_html_escapes_safely(&content[ref_begin_index + 1..ref_end_index].to_vec()),
+                    content[ref_begin_index + 1..ref_end_index].to_vec(),
                     vec![U16_DOUBLE_QUOTE, U16_SPACE, U16_SMALL_A, U16_SMALL_L, U16_SMALL_T, U16_EQUAL, U16_DOUBLE_QUOTE],
                     remove_special_characters(&content[curr_index + 1..link_end_index].to_vec()),
                     vec![U16_DOUBLE_QUOTE, U16_SPACE, U16_SMALL_T, U16_SMALL_I, U16_SMALL_T, U16_SMALL_L, U16_SMALL_E, U16_EQUAL, U16_DOUBLE_QUOTE],
@@ -33,7 +32,7 @@ pub fn render_link(content: &Vec<u16>) -> Vec<u16> {
             } else {
                 vec![
                     vec![U16_LESS_THAN, U16_SMALL_A, U16_SPACE, U16_SMALL_H, U16_SMALL_R, U16_SMALL_E, U16_SMALL_F, U16_EQUAL, U16_DOUBLE_QUOTE],
-                    undo_html_escapes_safely(&content[ref_begin_index + 1..ref_end_index].to_vec()),
+                    content[ref_begin_index + 1..ref_end_index].to_vec(),
                     vec![U16_DOUBLE_QUOTE, U16_GREATER_THAN],
                     render_link(&content[curr_index + 1..link_end_index].to_vec()),
                     vec![U16_LESS_THAN, U16_SLASH, U16_SMALL_A, U16_GREATER_THAN]
